@@ -4,7 +4,14 @@ from gemd.entity.setters import validate_list
 
 
 class HasConditions(object):
-    """Mixin-trait for entities that include conditions."""
+    """Mixin-trait for entities that include conditions.
+
+    Parameters
+    ----------
+    conditions: List[:class:`Condition <gemd.entity.attribute.condition.Condition>`]
+        A list of conditions associated with this entity.
+
+    """
 
     def __init__(self, conditions):
         self._conditions = None
