@@ -4,7 +4,14 @@ from gemd.entity.setters import validate_list
 
 
 class HasParameters(object):
-    """Mixin-trait for entities that include parameters."""
+    """Mixin-trait for entities that include parameters.
+
+    Parameters
+    ----------
+    parameters: List[:class:`Parameter <gemd.entity.attribute.parameter.Parameter>`]
+        A list of parameters associated with this entity.
+
+    """
 
     def __init__(self, parameters):
         self._parameters = None
