@@ -28,21 +28,22 @@ class MeasurementRun(BaseObject, HasConditions, HasProperties, HasParameters, Ha
         for filtering and discoverability.
     notes: str, optional
         Long-form notes about the measurement run.
-    conditions: List[Condition], optional
+    conditions: List[:class:`Condition <gemd.entity.attribute.condition.Condition>`], optional
         Conditions under which this measurement run occurs.
-    parameters: List[Parameter], optional
+    parameters: List[:class:`Parameter <gemd.entity.attribute.parameter.Parameter>`], optional
         Parameters of this measurement run.
-    properties: List[Property], optional
+    properties: List[:class:`Property <gemd.entity.attribute.property.Property>`], optional
         Properties that are measured during this measurement run.
-    spec: MeasurementSpec
+    spec: :class:`MeasurementSpec <gemd.entity.object.measurement_spec.MeasurementSpec>`
         The measurement specification of which this is an instance.
-    material: MaterialRun
+    material: :class:`MaterialRun <gemd.entity.object.material_run.MaterialRun>`
         The material run being measured.
-    spec: MaterialSpec
+    spec: :class:`MaterialSpec <gemd.entity.object.material_spec.MaterialSpec>`
         The material specification of which this is an instance.
-    file_links: List[FileLink], optional
+    file_links: List[:class:`FileLink <gemd.entity.file_link.FileLink>`], optional
         Links to associated files, with resource paths into the files API.
-    source: PerformedSource, optional
+    source: :class:`PerformedSource\
+    <gemd.entity.source.performed_source.PerformedSource>`, optional
         Information about the person who performed the run and when.
 
     """
