@@ -26,24 +26,25 @@ class ProcessRun(BaseObject, HasConditions, HasParameters, HasSource):
         for filtering and discoverability.
     notes: str, optional
         Long-form notes about the process run.
-    conditions: List[Condition], optional
+    conditions: List[:class:`Condition <gemd.entity.attribute.condition.Condition>`], optional
         Conditions under which this process run occurs.
-    parameters: List[Parameter], optional
+    parameters: List[:class:`Parameter <gemd.entity.attribute.parameter.Parameter>`], optional
         Parameters of this process run.
-    spec: ProcessSpec
+    spec: :class:`ProcessSpec <gemd.entity.object.process_spec.ProcessSpec>`
         Spec for this process run.
-    file_links: List[FileLink], optional
+    file_links: List[:class:`FileLink <gemd.entity.file_link.FileLink>`], optional
         Links to associated files, with resource paths into the files API.
-    source: PerformedSource, optional
+    source: :class:`PerformedSource\
+    <gemd.entity.source.performed_source.PerformedSource>`, optional
         Information about the person who performed the run and when.
 
     Attributes
     ----------
-    output_material: MaterialRun
+    output_material: :class:`MaterialRun <gemd.entity.object.material_run.MaterialRun>`
         The material run that this process run produces. The link is established by creating
         the material run and settings its `process` field to this process run.
 
-    ingredients: List[IngredientRun]
+    ingredients: List[:class:`IngredientRun <gemd.entity.object.ingredient_run.IngredientRun>`]
         Ingredient runs that act as inputs to this process run. The link is established by
         creating each ingredient run and setting its `process` field to this process run.
 
